==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectanglePP/ts/ShapeRectanglePP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>LineRectangle</name>
    <message>
        <source>First corner</source>
        <translatorcomment>--google--
Wskaż pierwszy wierzchołek</translatorcomment>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translatorcomment>--google--
Wskaż drugi wierzchołek</translatorcomment>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <source>&amp;Rectangle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Prostokąt</translatorcomment>
        <translation type="obsolete">&amp;Prostokąt</translation>
    </message>
    <message>
        <source>Draw rectangle from two corners</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj prostokąt od dwóch rogach</translation>
    </message>
</context>
<context>
    <name>ShapeRectangle</name>
    <message>
        <source>First corner</source>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <source>&amp;Rectangle</source>
        <translation type="obsolete">&amp;Prostokąt</translation>
    </message>
    <message>
        <source>Draw rectangle from two corners</source>
        <translation type="obsolete">Narysuj prostokąt od dwóch rogach</translation>
    </message>
</context>
<context>
    <name>ShapeRectanglePP</name>
    <message>
        <source>First corner</source>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <location filename="../ShapeRectanglePPInit.js" line="+2"/>
        <source>&amp;Rectangle</source>
        <translation type="unfinished">&amp;Prostokąt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle from two corners</source>
        <translation type="unfinished">Narysuj prostokąt od dwóch rogach</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Shape/ShapeRectanglePP/ts/ShapeRectanglePP_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LineRectangle</name>
    <message>
        <source>First corner</source>
        <translatorcomment>--google--
Wskaż pierwszy wierzchołek</translatorcomment>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translatorcomment>--google--
Wskaż drugi wierzchołek</translatorcomment>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <source>&amp;Rectangle</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Prostokąt</translatorcomment>
        <translation type="obsolete">&amp;Prostokąt</translation>
    </message>
    <message>
        <source>Draw rectangle from two corners</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Narysuj prostokąt od dwóch rogach</translation>
    </message>
</context>
<context>
    <name>ShapeRectangle</name>
    <message>
        <source>First corner</source>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <source>&amp;Rectangle</source>
        <translation type="obsolete">&amp;Prostokąt</translation>
    </message>
    <message>
        <source>Draw rectangle from two corners</source>
        <translation type="obsolete">Narysuj prostokąt od dwóch rogach</translation>
    </message>
</context>
<context>
    <name>ShapeRectanglePP</name>
    <message>
        <source>First corner</source>
        <translation type="obsolete">Pierwszy zakręt</translation>
    </message>
    <message>
        <source>Second corner</source>
        <translation type="obsolete">Drugi narożnik</translation>
    </message>
    <message>
        <location filename="../ShapeRectanglePPInit.js" line="+2"/>
        <source>&amp;Rectangle</source>
        <translation>&amp;Prostokąt</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw rectangle from two corners</source>
        <translation>Rysuje prostokąt z dwóch narożników</translation>
    </message>
</context>
</TS>
